// Replace a template with values from applicationVariables. Used to render the embedded app url,
// remote options url and headers.
// Modified from playlist-renderer/playlist-window-manager/src/embeddedApps.ts with the following changes:
//   1. Replaced applicationVersion.embeddedUrlFormat with 'template' so we can use this function for Remote Option urls and headers.
//   2. Replaced presentation argument with applicationVariables directly to support nested inputs like ArrayInput.
//   3. Replace applicationVersion argument with applicationVariables directly to support nested inputs like ArrayInput.
//   4. Pass token and renderMode directly.
//   5. Removed the metadata argument.
//   6. Return missing dependencies.
export default function replaceTemplateWithValues(template, applicationVariables, presentationProperties, token, renderMode) {
    // build matches
    const parameterRegex = /(:([\w-\$]+))(.?$|[^\w-\$])/gm;
    const matches = [];
    let match = null;
    do {
        match = parameterRegex.exec(template || '');
        if (match) {
            matches.push(match);
        }
    } while (match !== null);
    // replace
    let result = template;
    const missingDependencies = [];
    matches.forEach((m) => {
        const queryParamVariableName = m[1]; // Where the value of your input will be injected. E.g. ":location"
        const queryParamName = m[2]; // The query param name. E.g. "location"
        const [, variableName] = queryParamVariableName.split(':');
        let shouldEncodeValue = true;
        let value = undefined;
        let isValueRequired = false;
        if (variableName.charAt(0) === '$') {
            const metadataKey = variableName.slice(1);
            if (metadataKey === 'renderMode') {
                value = renderMode;
            }
            else if (metadataKey === 'token') {
                value = token;
                isValueRequired = true;
            }
        }
        else {
            // Don't replace variables that are numbers to allow setting
            // port numbers in the embedded app url.
            if (!isNaN(Number(variableName)))
                return;
            const presentationProperty = presentationProperties.find((p) => p.name === variableName);
            // If the presentation property is not found (this shouldn't happen), default to encoding the value.
            // Otherwise, only skip encoding if the presentation property's encode property is false.
            shouldEncodeValue =
                !presentationProperty || presentationProperty.encode !== false;
            value = applicationVariables[queryParamName];
            if ((presentationProperty === null || presentationProperty === void 0 ? void 0 : presentationProperty.optional) === false) {
                isValueRequired = true;
            }
            if (Array.isArray(value)) {
                value = JSON.stringify(value);
            }
            // Presentation property specific handling.
            if (presentationProperty) {
                // If the presentation property is a file, use the url property as the value.
                if (presentationProperty.type === 'file' && value && value.url) {
                    value = value.url;
                }
            }
        }
        if (value === undefined) {
            if (isValueRequired) {
                missingDependencies.push(variableName);
            }
            // If the value is undefined, replace the variable with an empty string to avoid "undefined" in the URL.
            value = '';
        }
        if (shouldEncodeValue) {
            value = encodeURIComponent(value);
        }
        result = result.replace(queryParamVariableName, value);
    });
    return { result, missingDependencies };
}
//# sourceMappingURL=replaceTemplateWithValues.js.map